@@ -1,4 +1,4 @@
-# Copyright (c) 2005-2007 Canonical
+# Copyright (c) 2005-2009 Canonical Ltd
 #
 # AUTHOR:
 # Michael Vogt <mvo@ubuntu.com>
@@ -46,19 +46,13 @@ import re
 from DebPackage import DebPackage, Cache
 from SimpleGladeApp import SimpleGladeApp
 from apt.progress import InstallProgress
-from GDebiCommon import GDebiCommon
+from GDebiCommon import GDebiCommon, utf8
 from gettext import gettext as _
 
 # the timeout when the termial is expanded if no activity from dpkg
 # is happening 
 GDEBI_TERMINAL_TIMEOUT=4*60.0
 
-def utf8(str):
-  try:
-    return unicode(str).encode('utf-8')
-  except:
-    return unicode(str, 'latin1').encode('utf-8')
-
 class GDebi(SimpleGladeApp, GDebiCommon):
 
     def __init__(self, datadir, options, file=""):
@@ -127,7 +121,6 @@ class GDebi(SimpleGladeApp, GDebiCommon):
         
         self.window_main.set_sensitive(True)
 
-
     def _get_file_path_from_dnd_dropped_uri(self, uri):
         """ helper to get a useful path from a drop uri"""
         path = urllib.url2pathname(uri) # escape special chars
@@ -225,12 +218,12 @@ class GDebi(SimpleGladeApp, GDebiCommon):
 
         # set filelist
         buf = self.textview_filelist.get_buffer()
-        buf.set_text("\n".join(self._deb.filelist))
+        buf.set_text(utf8("\n".join(self._deb.filelist)))
 
         # check the deps
         if not self._deb.checkDeb():
             self.label_status.set_markup("<span foreground=\"red\" weight=\"bold\">"+
-                                         "Error: " +
+                                         _("Error: ") +
                                          self._deb._failureString +
                                          "</span>")
 	    self.button_install.set_label(_("_Install Package"))
@@ -313,6 +306,14 @@ class GDebi(SimpleGladeApp, GDebiCommon):
             self.open(fs.get_filename())
         fs.destroy()
 
+    def on_refresh_activate(self, widget):
+        #print "refresh"
+        self.window_main.set_sensitive(False)
+        self.openCache()
+        if self._deb:
+            self.open(self._deb.file)
+        self.window_main.set_sensitive(True)
+
     def on_about_activate(self, widget):
         #print "about"
         from Version import VERSION
@@ -321,6 +322,7 @@ class GDebi(SimpleGladeApp, GDebiCommon):
         self.dialog_about.hide()
 
     def on_button_install_clicked(self, widget):
+        self.install_completed=False
         # check if we actually have a deb, see #213725
         if not self._deb:
             err_header = _("File not found")
@@ -390,7 +392,7 @@ Install software from trustworthy software distributors only.
         #self._term.feed(str(0x1b)+"[2J")
         self.dialog_deb_install.set_transient_for(self.window_main)
         self.dialog_deb_install.show_all()
-        
+
         if len(self.install) > 0 or len(self.remove) > 0:
             # FIXME: use the new python-apt acquire interface here,
             # or rather use it in the apt module and raise exception
@@ -431,17 +433,23 @@ Install software from trustworthy software distributors only.
                 return 
     
         # install the package itself
-        self.label_action.set_markup("<b><big>"+_("Installing package file")+"</big></b>")
+        self.label_action.set_markup("<b><big>" +
+                                     _("Installing %s") % self._deb.pkgName+
+                                     "</big></b>")
         dprogress = self.DpkgInstallProgress(self._deb.file,
                                              self.label_install_status,
                                              self.progressbar_install,
                                              self._term,
                                              self.expander_install)
         dprogress.commit()
+        self.install_completed=True
         #self.label_action.set_markup("<b><big>"+_("Package installed")+"</big></b>")
         # show the button
         self.button_deb_install_close.set_sensitive(True)
         self.button_deb_install_close.grab_default()
+        #Close if checkbox is selected
+        if self.checkbutton_autoclose.get_active():
+            self.on_button_deb_install_close_clicked(None)
         self.label_action.set_markup("<b><big>"+_("Installation finished")+"</big></b>")
         if dprogress.exitstatus == 0:
             self.label_install_status.set_markup("<i>"+_("Package '%s' was installed") % os.path.basename(self._deb.file)+"</i>")
@@ -452,16 +460,13 @@ Install software from trustworthy software distributors only.
         # FIXME: Doesn't stop notifying
         #self.window_main.set_property("urgency-hint", 1)
 
-        # reopen the cache, reread the file, FIXME: add progress reporting
-        #self._cache = Cache(self.cprogress)
-        self._cache = Cache()
+        # reopen the cache, reread the file
+        self.openCache()
         if self._cache._depcache.BrokenCount > 0:
             err_header = _("Failed to completely install all dependencies")
             err_body = _("To fix this run 'sudo apt-get install -f' in a "
                          "terminal window.")
             self.show_alert(gtk.MESSAGE_ERROR, err_header, err_body)
-
-            #print "Autsch, please report"
         self.open(self._deb.file)
         
     def on_button_deb_install_close_clicked(self, widget):
@@ -469,10 +474,15 @@ Install software from trustworthy software distributors only.
         #self.window_main.set_property("urgency-hint", 0)
         self.dialog_deb_install.hide()
         self.window_main.set_sensitive(True)
+    
+    def on_checkbutton_autoclose_clicked(self, widget):
+        if self.install_completed:
+            self.on_button_deb_install_close_clicked(None)            
 
     def on_window_main_delete_event(self, *args):
         if self.window_main.get_property("sensitive"):
-            gtk.main_quit()
+            if gtk.main_level() > 0:
+                gtk.main_quit()
             return False
         else: 
             return True
@@ -660,9 +670,9 @@ Install software from trustworthy software distributors only.
         def pulse(self):
             at_item = min(self.currentItems + 1, self.totalItems)
             if self.currentCPS > 0:
-                self.progress.set_text(_("File %s of %s at %sB/s" % (at_item,self.totalItems,apt_pkg.SizeToStr(self.currentCPS))))
+                self.progress.set_text(_("File %s of %s at %sB/s") % (at_item,self.totalItems,apt_pkg.SizeToStr(self.currentCPS)))
             else:
-                self.progress.set_text(_("File %s of %s" % (at_item,self.totalItems)))
+                self.progress.set_text(_("File %s of %s") % (at_item,self.totalItems))
             self.progress.set_fraction(self.currentBytes/self.totalBytes)
             while gtk.events_pending():
                 gtk.main_iteration()
